Struct google_cloudfunctions1::CallFunctionResponse [−][src]
pub struct CallFunctionResponse {
pub execution_id: Option<String>,
pub result: Option<String>,
pub error: Option<String>,
}Response of CallFunction method.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations functions call projects (response)
Fields
execution_id: Option<String>
Execution id of function invocation.
result: Option<String>
Result populated for successful execution of synchronous function. Will not be populated if function does not return a result through context.
error: Option<String>
Either system or user-function generated error. Set if execution was not successful.