Struct google_cloudfunctions1::EventTrigger [−][src]
pub struct EventTrigger {
pub event_type: Option<String>,
pub resource: Option<String>,
pub service: Option<String>,
pub failure_policy: Option<FailurePolicy>,
}Describes EventTrigger, used to request events be sent from another service.
This type is not used in any activity, and only used as part of another schema.
Fields
event_type: Option<String>
Required. The type of event to observe. For example:
providers/cloud.storage/eventTypes/object.change and
providers/cloud.pubsub/eventTypes/topic.publish.
Event types match pattern providers/*/eventTypes/*.*.
The pattern contains:
- namespace: For example,
cloud.storageandgoogle.firebase.analytics. - resource type: The type of resource on which event occurs. For
example, the Google Cloud Storage API includes the type
object. - action: The action that generates the event. For example, action for a Google Cloud Storage Object is 'change'. These parts are lower case.
resource: Option<String>
Required. The resource(s) from which to observe events, for example,
projects/_/buckets/myBucket.
Not all syntactically correct values are accepted by all services. For example:
- The authorization model must support it. Google Cloud Functions
only allows EventTriggers to be deployed that observe resources in the
same project as the
CloudFunction. - The resource type must match the pattern expected for an
event_type. For example, anEventTriggerthat has anevent_typeof "google.pubsub.topic.publish" should have a resource that matches Google Cloud Pub/Sub topics.
Additionally, some services may support short names when creating an
EventTrigger. These will always be returned in the normalized "long"
format.
See each service's documentation for supported formats.
service: Option<String>
The hostname of the service that should be observed.
If no string is provided, the default service implementing the API will
be used. For example, storage.googleapis.com is the default for all
event types in the google.storage namespace.
failure_policy: Option<FailurePolicy>
Specifies policy for failed executions.