Struct google_cloudfunctions1::Location [−][src]
pub struct Location {
pub location_id: Option<String>,
pub labels: Option<HashMap<String, String>>,
pub display_name: Option<String>,
pub name: Option<String>,
pub metadata: Option<HashMap<String, String>>,
}A resource that represents Google Cloud Platform location.
This type is not used in any activity, and only used as part of another schema.
Fields
location_id: Option<String>
The canonical id for this location. For example: "us-east1".
labels: Option<HashMap<String, String>>
Cross-service attributes for the location. For example
{"cloud.googleapis.com/region": "us-east1"}
display_name: Option<String>
The friendly name for this location, typically a nearby city name. For example, "Tokyo".
name: Option<String>
Resource name for the location, which may vary between implementations.
For example: "projects/example-project/locations/us-east1"
metadata: Option<HashMap<String, String>>
Service-specific metadata. For example the available capacity at the given location.